; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "TheDrumSolo"
command = ~F, D, B, F, D, B, x+y
time = 40

[Command]
name = "ElectricAvenue"
command = ~F, D, B, D, F, x
time = 35

[Command]
name = "ElectricAvenue"   ;Same name as above
command = ~F, D, B, D, F, y
time = 35


;-| Special Motions |------------------------------------------------------
[Command]
name = "QCF_xy"
command = ~D, F, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "HCB_xy"
command = ~F, D, B, x+y

[Command]
name = "HCB_x"
command = ~F, D, B, x

[Command]
name = "HCB_y"
command = ~F, D, B, y

[Command]
name = "FDF_xy"
command = ~F, D, F, x+y

[Command]
name = "FDF_x"
command = ~F, D, F, x

[Command]
name = "FDF_y"
command = ~F, D, F, y

[Command]
name = "QCF_ab"
command = ~D, F, a+b

[Command]
name = "QCF_a"
command = ~D, F, a

[Command]
name = "QCF_b"
command = ~D, F, b

[Command]
name = "QCB_ab"
command = ~D, B, a+b

[Command]
name = "QCB_a"
command = ~D, B, a

[Command]
name = "QCB_b"
command = ~D, B, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = z
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.

[Statedef 955531] ;AI Architecture, Dizzy Characters
Ctrl = 0
anim = 0

[state -1, Shut Down]
Type = DestroySelf
Trigger1 = 0; !Root, AILevel
IgnoreHitPause = 1

[state -1, Variable Reset]
Type = VarSet
IgnoreHitPause = 1
FV = (0)
TriggerAll = Fvar(0) = fvar(1)
Trigger1 = Root,Time = 1
Trigger2 = Root,StateNo = [6060,6069]
Trigger3 = Enemy,Time = 1
Value = 0  

[state -1, Variable Reset]
Type = Null
IgnoreHitPause = 1 
Trigger1 = Time || fvar(38):= Root,P2BodyDist X*.5
Trigger2 = Time || fvar(39):= Root,P2BodyDist Y

;Dedicated Buffer Delegation / Other Functions
[State 955531]
Type = Null
IgnoreHitPause = 1
TriggerAll = Root, AILevel
TriggerAll = Root, Alive
;Tick Throw Walk - Low Kick
Trigger1 = Root, StateNo = 430
Trigger1 = Root, MoveGuarded = 1
;Tick Throw Walk
Trigger2 = Root, Ctrl || Root, StateNo = 20
Trigger2 = var(59) > 0
;Air Combo
Trigger3 = Root, StateNo = [6060,6061]
Trigger3 = P2StateNo = 5020 || P2StateNo = 5030 || P2StateNo = 5050
Trigger4 = Var(58) > 0
Trigger5 = var(59) < 0
Trigger6 = var(58) < 0
trigger7 = P2StateNo = 5120 || Enemy, PrevStateNo = 5120
trigger8 = var(57) > 0 
trigger9 = var(57) < 0 
;------------------------------------------
Trigger1 = var(59) := 10
Trigger2 = var(59) := var(59) - cond( Enemy, Ctrl, 2, 1 )
Trigger3 = var(58) := 15
Trigger4 = var(58) := var(58) - 1
Trigger5 = var(59) := 0
Trigger6 = var(58) := 0
trigger7 = var(57) := 20
trigger8 = var(57) := var(57) - 1
trigger9 = var(57) := 0
;------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0

[state 955531, Full AI Programming, Anti-Air]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	fvar(38) >= 0
triggerall	=	!InGuardDist&&!Root, InGuardDist||Enemy, time>=10         ;Not within guard distance
Triggerall	=	fvar(0) = 0 || Random < 100  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
trigger1	=	fvar(38) < 20
Trigger1	=	Root, StateType != A;	;Set for appropriate StateType
trigger1	=	Root, ctrl
trigger1	=	p2stateno !=[5000,5300]
trigger1	=	p2statetype=A
trigger1	=	enemy, vel y >= -3
trigger1	=	enemy, time <= ceil(fvar(2) / 2)
trigger1	=	enemy, pos y < -15
trigger2	=	fvar(38) < 30
Trigger2	=	Root, StateType = A;	;Set for appropriate StateType
trigger2	=	Root, ctrl
trigger2	=	p2stateno !=[5000,5300]
trigger2	=	p2statetype=A
;----------------------------------------------------------------------
Trigger1	=	floor(fvar(0) := 1030)
Trigger2	=	floor(fvar(0) := cond( root, p2dist y < 0, 630, 600 ))
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 955531, Full AI Programming, Air to Ground]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
TriggerAll	=	Root, StateType = A
triggerall	=	!InGuardDist&&!Root, InGuardDist||Enemy, time>=10         ;Not within guard distance
TriggerAll	=	fvar(0) = 0 || Random < 160  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AiLevel
Trigger1 = fvar(38) <= 41
Trigger1 = Root, vel y >= -1.9
Trigger1 = P2StateType = S || var(57) > 0
Trigger2 = Root, StateNo = 630
Trigger2 = Root, MoveContact = 1
Trigger3 = Root, StateNo = 600
Trigger3 = Root, MoveContact = 1
;----------------------------------------------------------------------
Trigger1 = floor(fvar(0) := 630+((var(57)> 0) * 10))
Trigger2 = floor(fvar(0) := 640)
Trigger3 = floor(fvar(0) := 610)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0


[state 955531, Full AI Programming, Dizzy Cancel Buffer]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
triggerall	=	var(0) > 0
triggerall	=	!InGuardDist&&!Root, InGuardDist||Enemy, time>=ceil(fvar(2) / 4)
TriggerAll	=	fvar(0) = 0 || Random < 160  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
triggerAll	=	Root, Time <= var(0) && Root, Ctrl 
TriggerAll	=	 !fvar(3) 
trigger1	=	fvar(38) <= 35 
Trigger1	=	Root, StateType != A;	;Set for appropriate StateType
Trigger1	=	p2statetype = S || P2StateType = C
Trigger2	=	fvar(38)<=90  ;Horizontal distance (maximum range)
Trigger2	=	Root, StateType != A;	;Set for appropriate StateType
Trigger2	=	P2StateType != A   ;vertical distance (non-anti-air situations)
trigger2	=	fvar(38) > 35 ;randomizer
trigger2	=	P2StateNo != 5050 ;not in hitfall
trigger2	=	p2statetype!=L         ;standard state conditions
;----------------------------------------------------------------------
trigger1	=	floor(fvar(0) := 430)
trigger2	=	floor(fvar(0) := 210)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0

[state 955531, Full AI Programming, Hit Link]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
TriggerAll	=	fvar(0) = 0 || Random < 160  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel && Root, AILevel > 6
triggerAll	=	Root, ctrl && !fvar(3) 
TriggerAll	=	P2StateNo = 5001 || P2StateNo = 5011 || P2StateNo != 5035 && (P2StateNo = [5020,5040]) || P2StateNo = [130,159]
trigger1	=	fvar(38) <= 35
trigger1	=	root, time >= (root, prevstateno = [200,499]) * 2
Trigger1	=	Root, StateType != A;	;Set for appropriate StateType
Trigger1	=	p2statetype = S || P2StateType = C
Trigger2	=	P2StateType = A
;----------------------------------------------------------------------
trigger1	=	floor(fvar(0) := 430+cond(random<30&&fvar(38) > 35,10,0))
trigger2	=	floor(fvar(0) := 1010)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0

[state 955531, Full AI Programming, Standard]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
triggerall	=	!InGuardDist&&!Root, InGuardDist||Enemy, time>=ceil(fvar(2) / 4)
TriggerAll	=	fvar(0) = 0 || Random < 160  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
TriggerAll	=	P2MoveType != H || Root, PrevStateNo = 52 && Root, Time <= 4
triggerAll	=	Root, ctrl && !fvar(3) 
;-------------------------------------------------------------------------
trigger1	=	fvar(38) < 3
Trigger1	=	Root, StateType != A;	;Set for appropriate StateType
trigger1	=	gametime % 5 = 1 || var(59) || Root, time <= 5
trigger1	=	p2stateno !=[5000,5300]
trigger1	=	p2statetype=S||p2statetype=C
trigger1	=	root, prevstateno != 52
Trigger2	=	Root, StateType != A
Trigger2	=	Cond( (Enemy, Ctrl && fvar(38) = [80, 110]), Random <= 120, Enemy, vel x <= 0 && (fvar(38) = [(P2Movetype != H) * 3,48]) )
trigger2	=	P2StateType = S || P2StateType = C
trigger2	=	root, time >= (root, prevstateno = [200,499]) * 2
Trigger3	=	Root, StateType != A
Trigger3	=	P2MoveType = I
Trigger3	=	P2StateType = L || P2StateType = S
Trigger3	=	fvar(38) = [40, 80]
trigger3	=	Random <= 36 + (abs( root,p2bodydist x - root,p2dist x ))
Trigger4	=	P2StateNo = [5050,5110] 
Trigger4	=	fvar(38) > 110
;----------------------------------------------------------------------
trigger1	=	floor(fvar(0) := 800)
trigger2	=	floor(fvar(0) := cond(p2movetype!=H&&random%99<(8**root,time),210,430))
trigger3	=	floor(fvar(0) := 1010)
trigger4	=	floor(fvar(0) := 1000)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0

[state 955531, Full AI Programming, Supers]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
TriggerAll	=	fvar(0) = 0 || Random < 100    ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
triggerall	=	power >= 1000
TriggerAll	=	Root, AILevel
Trigger1	=	0;Root, StateNo = 215 
trigger1	=	Root, HitCount > 1
trigger1	=	random < 250 * (1 * Root, var(3))
trigger1	=	Root, MoveHit = 1
trigger2	=	Root, ctrl
trigger2	=	Root, inguarddist&&inguarddist
trigger2	=	Root, p2dist x >= 0
Trigger2	=	Root, P2Dist Y >= -30
trigger2	=	Enemy, vel y >= (p2statetype = A)
;----------------------------------------------------------------------
trigger1	=	floor(fvar(0) := 3000) 
trigger2	=	floor(fvar(0) := 3000)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 955531, Full AI Programming, MoveContact]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
TriggerAll	=	fvar(0) = 0 || Random < 120  ;AI only
triggerAll	=	Root, MoveHit = 1 || (Random%99 < 2**Root,MoveGuarded) 
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
Trigger1	=	Root, StateNo = 215 || Root, StateNo = 210
trigger1	=	Root, Time >= cond(root, stateno = 210, 19, 23) || Root, HitCount > 1                      ;combo condition
Trigger1	=	Random <= 200 * cond(root, stateno = 210 && P2StateType != C, 1, 5)
trigger1	=	P2StateNo != [120,159]
Trigger2	=	Root, StateNo = 230 || Root, StateNo = 200 || Root, StateNo = 400 || Root, StateNo = 430
trigger2	=	P2StateNo != [120,159]
Trigger3	=	Root, StateNo = 230                      ;combo condition
Trigger4	=	Root, StateNo = 410                      ;combo condition
Trigger5	=	Root, StateNo = 210 
trigger5	=	Root, Time >= 19                    ;combo condition
;----------------------------------------------------------------------
trigger1	=	floor(fvar(0) := cond( root, var(3) < 3 && Power >= 550, cond(random < 667, 1000, 1040), cond(power >= 550, 1000, 1010) ))
trigger2	=	floor(fvar(0) := 210)
trigger3	=	floor(fvar(0) := 210)
trigger4	=	floor(fvar(0) := 1000)
trigger5	=	floor(fvar(0) := 215)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 955531, Full AI Programming, Movement]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
TriggerAll	=	fvar(0) = 0 || Random < 100   ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
triggerall	=	Root, ctrl
Triggerall	=	Root, StateType = S;	;Set for appropriate StateType
trigger1	=	!InGuardDist&&!Root, InGuardDist         ;Not within guard distance
trigger1	=	 P2StateNo = [5050,5110]
trigger2	=	!InGuardDist&&!Root, InGuardDist         ;Not within guard distance
trigger2	=	random < cond(P2StateNo >= 160, 400, 80) || enemy, facing = facing 
trigger2	=	fvar(38) > cond( p2movetype = A, 35, 100)
trigger3	=	!InGuardDist&&!Root, InGuardDist         ;Not within guard distance
Trigger3	=	fvar(38) < 60
trigger3	=	Enemy, hitdefattr = SCA, AT || (P2StateNo = [5100,5110]) 
trigger4	=	!InGuardDist||Root, InGuardDist         ;Not within guard distance
trigger4	=	P2BodyDist X >= 30
Trigger4	=	fvar(38) > 130
;----------------------------------------------------------------------
trigger1	=	floor(fvar(0) := 100)
trigger2	=	floor(fvar(0) := 100)
trigger3	=	floor(fvar(0) := 105)
trigger4	=	floor(fvar(0) := 100)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 955531, Full AI Programming, Dizzy Cancels]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
TriggerAll	=	fvar(0) = 0 || Random < 100   ;AI only
TriggerAll	=	Root, StateNo != [6060,6062]
TriggerAll	=	Root, PrevStateNo != [6060,6062]
TriggerAll	=	Root, MoveType = A
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
triggerall	=	power >= cond( Root, AILevel > 6, 550, 1000 ) 
TriggerAll	=	root, var(3) < 3
TriggerAll	=	Root, AILevel
Triggerall	=	random <= ceil(1000 / (1 + Root, var(3))) || P2StateType = C
trigger1	=	Root, MoveHit = 1
Trigger1	=	Root, StateNo = 1042  
Trigger2	=	Root, NumProjID(999999) > 0 ;Detect Hit
;----------------------------------------------------------------------
trigger1	=	floor(fvar(0) := 6060 && var(0) := 12) 
trigger2	=	floor(fvar(0) := 6060 && var(0) := 12)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 955531, Full AI Programming, Jump]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
TriggerAll	=	fvar(0) = 0 || Random < 100   ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
Triggerall	=	Root, StateType = S;	;Set for appropriate StateType
trigger1	=	Root, ctrl
trigger1	=	!InGuardDist&&!Root, InGuardDist         ;Not within guard distance
trigger1	=	P2MoveType = I
trigger1	=	P2StateType = L
trigger1	=	Enemy, Time <= ceil(fvar(2) / 3)
trigger1	=	random < 170
trigger2	=	Root, ctrl
trigger2	=	!InGuardDist&&!Root, InGuardDist         ;Not within guard distance
trigger2	=	random < cond(P2StateNo >= 160, 110, 90)
trigger2	=	fvar(38) > 100
Trigger2	=	P2MoveType != A
trigger3	=	Root, ctrl
trigger3	=	!InGuardDist&&!Root, InGuardDist         ;Not within guard distance
Trigger3	=	fvar(38) < 60
trigger3	=	Enemy, hitdefattr = , AT
trigger4	=	!Root, InGuardDist || InGuardDist         ;Not within guard distance
Trigger4	=	P2MoveType = A
trigger4	=	P2BodyDist X >= 30
Trigger4	=	fvar(38) = [90,130]
trigger4	=	root, stateno = 100
;----------------------------------------------------------------------
Trigger1	=	(fvar(0) := 40)
Trigger2	=	(fvar(0) := 40)
Trigger3	=	(fvar(0) := 40)
Trigger4	=	(fvar(0) := 40)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 0, bind]
type=turn
Trigger1=facing!=Root, facing

[state 0, bind]
type=PosSet
Trigger1=1
X = 0
Y = 0

[State 0, AssertSpecial]
Type = AssertSpecial
Trigger1 = 1
Flag = Invisible
Flag = NoShadow

[State 0, NotHitBy]
Type = NotHitBy
Trigger1 = 1
Value = SCA,NA,SA,HA,NP,SP,HP,NT,ST,HT
Time = -1

[state -1, Variable Reset]
Type = VarAdd
IgnoreHitPause = 1
V = (0)
Trigger1 = var(0) > 0 
trigger1 = root, stateno != [6060,6062] 
Value = -1

[state -1, Variable Reset]
Type = VarSet
IgnoreHitPause = 1
FV = (1)
trigger1 = fvar(0) != 0 
Value = fvar(0)

[state -1, WHAT ARE THEY DOING]
Type = VarSet
IgnoreHitPause = 1
FV = (2)
trigger1 = cond( p2statetype = A, !enemy, time, p2statetype != A)
value = abs(enemy, animtime) + enemy, time

[state -1, OW WHO DID THAT]
Type = VarSet
IgnoreHitPause = 1
FV = (3)
trigger1 = Root, StateNo = [5000,5270]
Trigger1 = !fvar(3)
Value = 10
[state -1, Recently Hit Check]
Type = VarAdd
IgnoreHitPause = 1
FV = (3)
trigger1 = Root, StateNo != [5000,5270]
Trigger1 = fvar(3) > 0
Value = -1
[state -1, Guard cancel]
Type = VarSet
IgnoreHitPause = 1
FV = (4)
trigger1 = Root, StateNo = [6070,6072]
Trigger1 = !fvar(4)
Value = 10
[state -1, Recent Guard Cancel Check]
Type = VarAdd
IgnoreHitPause = 1
FV = (4)
trigger1 = Root, StateNo != [6070,6072]
Trigger1 = fvar(4) > 0
Value = -1
[state -1, Guard Check]
Type = VarSet
IgnoreHitPause = 1
FV = (5)
trigger1 = Root, StateNo = [150,159]
Trigger1 = !fvar(5)
Value = 10
[state -1, Recent Guard Check]
Type = VarAdd
IgnoreHitPause = 1
FV = (5)
trigger1 = Root, StateNo != [120,159]
Trigger1 = fvar(5) > 0
Value = -1

[State -1, YOU WA PROJDETECT]
Type = Null
TriggerAll = 0
Trigger1 = 1
trigger2 = Time <= 10
Trigger3 = RoundState = 0
Trigger3 = Root, TeamMode = Simul || Enemy, TeamMode = Simul
Trigger4 = var(10) > 5 + var(11)
trigger5 = var(10) >= var(11)
trigger5 = playeridexist(var(10))
Trigger1 = var(10) := var(10) + 3
Trigger2 = var(11) := (Root, numhelper)+(enemy,numhelper)+(var(12))+(id)+1
Trigger3 = var(12) := var(12) + 1
Trigger4 = var(10) := var(11)
trigger5 = var(11) := var(10)
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0

[State 0, Display To ClipBoard]
Type = DisplayToClipBoard
Text = "RootDist = %d, Enemy X,Y = %d %d, GetUp: %d \naction = %d %d"
params = rootdist x, fvar(38),fvar(39), var(57), fvar(0),fvar(1)
trigger1 = 1
[State 0, Display To ClipBoard]
Type = AppendToClipBoard
Text = " Fvar2: %d GuDi?: %d P2ST: %d Vel: %d %d RNP: %d"
params = fvar(2), InGuardDist + Root,InGuardDist,P2StateNo, root,vel x, root,vel y,root,numprojid(999999)
trigger1 = 1
; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
[State -3, AI Helper Hit Detect]
Type = Projectile
TriggerAll	=	AILevel
TriggerAll	=	!NumProjID(999999)
TriggerAll	=	RoundState = 2
Trigger1	=	NumHelper(1006)
Trigger1 	= 	Helper(1006), MoveHit = 1
projremovetime = 1
projsprpriority = -999
projid = 999999
Offset = -999999, -999999
projanim = 9999	
[State -3, Helper]
Type = Helper
TriggerAll	=	!IsHelper
Trigger1 	= 	!NumHelper(955531)
name = "Ritsu's AI"
ID = 955531
StateNo = 955531
pos = 0,0
posType = p1
facing = 1
ownpal = 0

[State 5050, 4] ;Recover near ground
type = ChangeState
triggerall = Vel Y > 0
triggerall = Pos Y >= Const(movement.air.gethit.groundrecover.ground.threshold)
triggerall = alive
triggerall = CanRecover
trigger1 = AILevel
Trigger1 = StateNo = 5050
value = 5200 ;Air get-hit (fall recovery on ground)

[State 5050, 5]; Recover in mid air
type = ChangeState
triggerall = Vel Y > Const(movement.air.gethit.airrecover.threshold)
triggerall = alive
triggerall = CanRecover
trigger1 = AILevel
Trigger1 = StateNo = 5050
value = 5210 ;Air get-hit (fall recovery in air)


[state -1, AI Jump]
Type = VarSet
IgnoreHitPause = 1
Trigger1 = enemy, Vel X = 0
Trigger1 = P2StateType = A || P2StateNo = 5120
Trigger1 = PrevStateNo != 100
trigger1 = AILevel
sysvar(1) = 0

[state -1, AI Jump]
Type = VarSet
IgnoreHitPause = 1
Trigger1 = enemy, Vel X <= 0  
trigger1 = numhelper(955531)
trigger1 = helper(955531),fvar(38) >= 50
trigger1 = p2statetype = S || !InGuardDist
Trigger1 = PrevStateNo != 100
trigger1 = AILevel
sysvar(1) = 1

[state -1, AI Jump]
Type = VarSet
IgnoreHitPause = 1
trigger1 = numhelper(955531)
trigger1 = AILevel
Trigger1 = PrevStateNo = 100
sysvar(1) = 1

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact
var(1) = 1

;---------------------------------------------------------------------------
;The Drum Solo (Hyper)
[State -1, The Drum Solo (Hyper)]
type = ChangeState
value = 3050
triggerall = command = "TheDrumSolo" && !AILevel || Helper(955531), fvar(0) = 2050
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Electric Avenue (Hyper)
[State -1, Electric Avenue (Hyper)]
type = ChangeState
value = 3000
triggerall = command = "ElectricAvenue" && !AILevel || Helper(955531), fvar(0) = 3000 
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Lightning Cross (Air) (Light)
[State -1, Lightning Cross (Air) (Light)]
type = ChangeState
value = 1200
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 1200||!AILevel && command = "HCB_x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640) && movecontact

;---------------------------------------------------------------------------
;Lightning Cross (Air) (Strong)
[State -1, Lightning Cross (Air) (Strong)]
type = ChangeState
value = 1200
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 1200||!AILevel && command = "HCB_y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640) && movecontact

;---------------------------------------------------------------------------
;Lightning Cross (Light)
[State -1, Lightning Cross (Light)]
type = ChangeState
value = 1060
triggerall = command = "HCB_x" && !AILevel || Helper(955531), fvar(0) = 1060
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Lightning Cross (Strong)
[State -1, Lightning Cross (Strong)]
type = ChangeState
value = 1070
triggerall = command = "HCB_y" && !AILevel || Helper(955531), fvar(0) = 1070
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;California Romance (Strong)
[State -1, California Romance (Strong)]
type = ChangeState
value = 1050
triggerall = command = "FDF_xy" && !AILevel || Helper(955531), fvar(0) = 1050
triggerall = power >= 500
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;California Romance (Light)
[State -1, California Romance (Light)]
type = ChangeState
value = 1030
triggerall = command = "FDF_x" && !AILevel || Helper(955531), fvar(0) = 1030
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;California Romance (Strong)
[State -1, California Romance (Strong)]
type = ChangeState
value = 1040
triggerall = command = "FDF_y" && !AILevel || Helper(955531), fvar(0) = 1040
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Grand Blaster (EX)
[State -1, Grand Blaster (EX)]
type = ChangeState
value = 1020
triggerall = command = "QCF_xy" && !AILevel || Helper(955531), fvar(0) = 1020
triggerall = power >= 500
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Grand Blaster (Light)
[State -1, Grand Blaster (Light)]
type = ChangeState
value = 1000
triggerall = command = "QCF_x" && !AILevel || Helper(955531), fvar(0) = 1000
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Grand Blaster (Strong)
[State -1, Grand Blaster (Strong)]
type = ChangeState
value = 1010
triggerall = command = "QCF_y" && !AILevel || Helper(955531), fvar(0) = 1010
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Drum Shot (EX)
[State -1, Drum Shot (EX)]
type = ChangeState
value = 1120
triggerall = command = "QCF_ab" && !AILevel || Helper(955531), fvar(0) = 1120
triggerall = power >= 500
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Drum Shot (Light)
[State -1, Drum Shot (Light)]
type = ChangeState
value = 1100
triggerall = command = "QCF_a" && !AILevel || Helper(955531), fvar(0) = 1100
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Drum Shot (Strong)
[State -1, Drum Shot (Strong)]
type = ChangeState
value = 1110
triggerall = command = "QCF_b" && !AILevel || Helper(955531), fvar(0) = 1110
trigger1 = var(1) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF" && !AILevel || Helper(955531), fvar(0) = 100
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB" && !AILevel || Helper(955531), fvar(0) = 105
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = command = "y" && !AILevel 
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 6
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = Helper(955531), fvar(0) = 800
triggerall = statetype != A
triggerall = ctrl
triggerall = stateno != 100
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x" && !AILevel 
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 
trigger2 = time > 12

;---------------------------------------------------------------------------
;Stand Strong Punch (Secondary)
[State -1, Stand Strong Punch (Secondary)]
type = ChangeState
value = 215
triggerall = command = "y" && !AILevel 
triggerall = command = "holdfwd"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y" && !AILevel 
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a" && !AILevel 
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = time > 12

;---------------------------------------------------------------------------
;Stand Strong Kick
[State -1, Stand Strong Kick]
type = ChangeState
value = 240
triggerall = command = "b" && !AILevel 
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start" && !AILevel 
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x" && !AILevel 
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "y" && !AILevel 
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno  = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a" && !AILevel 
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 430 
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = command = "b" && !AILevel 
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x" && !AILevel || Helper(955531), fvar(0) = 600
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = time > 12

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y" && !AILevel || Helper(955531), fvar(0) = 610
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a" && !AILevel || Helper(955531), fvar(0) = 630
trigger1 = statetype = A
trigger1 = ctrl 
trigger2 = stateno = 630
trigger2 = time > 30

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "b" && !AILevel || Helper(955531), fvar(0) = 640
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
; Dizzy Cancel (Stand)
[State -1, |Dizzy Cancel Stand|]
type = ChangeState
value = 6060+(statetype = S)
triggerall =  movetype != H
triggerall = statetype != C
triggerall = var(3) < 3
triggerall = command = "c" && !AILevel || Helper(955531), fvar(0) = 6060
triggerall = power > 500
trigger1 = (stateno = [600,699]) || (stateno = [1130,1141]) || (stateno = [1201,1211])
trigger1 = movehit
trigger2 = (stateno = [200,499]) || (stateno = [1100,1111])
trigger2 = movehit
trigger3 = (stateno = [1030,1045]) || (stateno = [1060,1071])
trigger3 = movehit
trigger4 = numhelper(1006)
trigger4 = helper(1006),movehit
trigger5 = numhelper(1016)
trigger5 = helper(1016),movehit
;---------------------------------------------------------------------------
; Dizzy Cancel (Crouch)
[State -1, |Dizzy Cancel Crouch|]
type = ChangeState
value = 6062
triggerall =  movetype != H
triggerall = statetype = C
triggerall = var(3) < 3
triggerall = command = "c" && !AILevel || Helper(955531), fvar(0) = 6061
triggerall = power > 500
trigger1 = (stateno = [600,699]) || (stateno = [1130,1141]) || (stateno = [1201,1211])
trigger1 = movehit
trigger2 = (stateno = [200,499]) || (stateno = [1100,1111])
trigger2 = movehit
trigger3 = (stateno = [1030,1045]) || (stateno = [1060,1071])
trigger3 = movehit
trigger4 = numhelper(1006)
trigger4 = helper(1006),movehit
trigger5 = numhelper(1016)
trigger5 = helper(1016),movehit

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Air)
[State -1, |Dizzy Guard Cancel Air|]
type = ChangeState
value = 6070
triggerall =  movetype = H
triggerall = statetype = A
triggerall = command = "z" && !AILevel || AILevel && random < 80
triggerall = power > 1000
trigger1 = stateno = 154

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Stand)
[State -1, |Dizzy Guard Cancel Stand|]
type = ChangeState
value = 6071
triggerall =  movetype = H
triggerall = statetype = S
triggerall = command = "z"  && !AILevel || AILevel && random < 80
triggerall = power > 1000
trigger1 = stateno = 150

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Crouch)
[State -1, |Dizzy Guard Cancel Crouch|]
type = ChangeState
value = 6072
triggerall =  movetype = H
triggerall = statetype = C
triggerall = command = "z"  && !AILevel || AILevel && random < 80
triggerall = power > 1000
trigger1 = stateno = 152

;---------------------------------------------------------------------------

;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = Helper(955531), fvar(0) = 200
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 
trigger2 = time > 12

;---------------------------------------------------------------------------
;Stand Strong Punch (Secondary)
[State -1, Stand Strong Punch (Secondary)]
type = ChangeState
value = 215
triggerall = Helper(955531), fvar(0) = 215
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = Helper(955531), fvar(0) = 210
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = Helper(955531), fvar(0) = 230
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = time > 12

;---------------------------------------------------------------------------
;Stand Strong Kick
[State -1, Stand Strong Kick]
type = ChangeState
value = 240
triggerall = Helper(955531), fvar(0) = 240
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = Helper(955531), fvar(0) = 400
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = Helper(955531), fvar(0) = 410
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno  = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = Helper(955531), fvar(0) = 430
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 430 
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = Helper(955531), fvar(0) = 440
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

[State -1, Jump AI]
type = ChangeState
value = 40
triggerall = AILevel
triggerall = StateType != A
Trigger1 = Helper(955531), fvar(0) = 40
Trigger1 = Helper(955531), fvar(1) = 40
trigger1 = ctrl || stateno = 100

[State -3, Jump Light Kick]
type = ChangeState
value = 120
triggerall = AILevel
triggerall = InGuardDist
TriggerAll = StateNo != [120,159]
trigger1 = Ctrl

[State -3, Jump Light Kick]
type = ChangeState
value = 130
triggerall =AILevel
triggerall = statetype = C
triggerall = stateno = 120 || stateno = 131
trigger1 = p2statetype = A 
trigger2 = (helper(955531), fvar(2) / 7) + random%16 > 8 ; - random % 10
trigger2 = P2StateType = S

[State -3, Jump Light Kick]
type = ChangeState
value = 131
triggerall =AILevel
triggerall = statetype = S
triggerall = stateno = 120 || stateno = 130
trigger1 = P2StateType = C
trigger2 = p2statetype != A 
trigger2 = helper(955531), fvar(2) / 7 <= 8 ; - random % 10 

[State -3, Jump Light Kick]
type = StateTypeSet
statetype = S
Physics = S
triggerall =AILevel
triggerall = statetype = C
triggerall = stateno = 120 || stateno = 131 || stateno = [153,154]
trigger1 = p2statetype = A 
trigger2 = (helper(955531), fvar(2) / 7) + random%16 > 8 ; - random % 10
trigger2 = P2StateType = S

[State -3, Jump Light Kick]
type = StateTypeSet
statetype = C
Physics = C
triggerall =AILevel
triggerall = statetype = S
triggerall = stateno = 120 || stateno = 130 || stateno = [151,152]
trigger1 = P2StateType = C
trigger2 = p2statetype != A 
trigger2 = helper(955531), fvar(2) / 7 <= 8 ; - random % 10 


[State -1, Jump Lock]
type = ChangeState
value = 0
CTRL = 1
triggerall = AILevel
triggerall = statetype != A
Trigger1 = Helper(955531), fvar(1) != 40
trigger1 = stateno = 40
